@@ -2,6 +2,8 @@
 #define SIZEOF_INT 4
 #define SIZEOF_SHORT 2
 #define SIZEOF_LONG 4
+#define SIZEOF_LONG_LONG 8
+#define SIZEOF___INT64 0
 #define SIZEOF_VOIDP 4
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
@@ -28,6 +30,7 @@
 #define HAVE_A_OUT_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_MEMORY_H 1
+#define HAVE_SYS_RESOURCE_H 1
 #define HAVE_ST_BLKSIZE 1
 #define HAVE_ST_BLOCKS 1
 #define HAVE_ST_RDEV 1
@@ -44,7 +47,6 @@
 #define HAVE_STRCHR 1
 #define HAVE_STRSTR 1
 #define HAVE_STRTOUL 1
-#define HAVE_STRDUP 1
 #define HAVE_CRYPT 1
 #define HAVE_FLOCK 1
 #define HAVE_VSNPRINTF 1
@@ -59,11 +61,15 @@
 #define HAVE_WAITPID 1
 #define HAVE_SYSCALL 1
 #define HAVE_GETCWD 1
+#define HAVE_CHROOT 1
 #define HAVE_TRUNCATE 1
 #define HAVE_TIMES 1
 #define HAVE_UTIMES 1
 #define HAVE_FCNTL 1
 #define HAVE_LOCKF 1
+#define HAVE_LSTAT 1
+#define HAVE_SYMLINK 1
+#define HAVE_READLINK 1
 #define HAVE_SETITIMER 1
 #define HAVE_SETRUID 1
 #define HAVE_SETEUID 1
@@ -71,26 +77,32 @@
 #define HAVE_SETRGID 1
 #define HAVE_SETEGID 1
 #define HAVE_SETREGID 1
+#define HAVE_PAUSE 1
 #define HAVE_GETPGRP 1
 #define HAVE_SETPGRP 1
 #define HAVE_GETPGID 1
 #define HAVE_SETPGID 1
 #define HAVE_GETGROUPS 1
 #define HAVE_GETPRIORITY 1
+#define HAVE_GETRLIMIT 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
 #define HAVE__SETJMP 1
 #define HAVE_SETSID 1
+#define HAVE_TELLDIR 1
+#define HAVE_SEEKDIR 1
+#define HAVE_FCHMOD 1
 #define HAVE_TM_ZONE 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
 #define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _r
+#define DEFAULT_KCODE KCODE_NONE
 #define DLEXT ".so"
-#define RUBY_LIB "/usr/local/lib/ruby/1.4"
+#define RUBY_LIB "/usr/local/lib/ruby/1.6"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
-#define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.4"
-#define RUBY_PLATFORM "i386-openbsd2.8"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.4/i386-openbsd2.8"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.4/i386-openbsd2.8"
+#define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.6"
+#define RUBY_PLATFORM "i386-openbsd2.9"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.6/i386-openbsd2.9"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.6/i386-openbsd2.9"
