@@ -1,20 +1,22 @@
 
 module Config
 
-  VERSION == "1.4.6" or
-    raise "ruby lib version (1.4.6) doesn't match executable version (#{VERSION})"
+  VERSION == "1.6.2" or
+    raise "ruby lib version (1.6.2) doesn't match executable version (#{VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
+  DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
-  CONFIG["srcdir"] = "/usr/ports/lang/ruby/work/ruby-1.4.6"
-  CONFIG["prefix"] = "/usr/local"
+  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-openbsd2\.9\Z', '')
+  CONFIG["srcdir"] = "/usr/ports/lang/ruby/work/ruby-1.6.2"
+  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ""
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["CFLAGS"] = "-O2    -fPIC"
+  CONFIG["CFLAGS"] = "-O2 -pipe   -fPIC"
   CONFIG["CPPFLAGS"] = ""
-  CONFIG["CXXFLAGS"] = "-O2   "
+  CONFIG["CXXFLAGS"] = "-O2 -pipe  "
   CONFIG["FFLAGS"] = ""
   CONFIG["LDFLAGS"] = ""
   CONFIG["LIBS"] = "-lm "
@@ -32,54 +34,80 @@ module Config
   CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
   CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
   CONFIG["MAJOR"] = "1"
-  CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "6"
-  CONFIG["host"] = "i386-unknown-openbsd2.8"
-  CONFIG["host_alias"] = "i386-unknown-openbsd2.8"
+  CONFIG["MINOR"] = "6"
+  CONFIG["TEENY"] = "2"
+  CONFIG["host"] = "i386-unknown-openbsd2.9"
+  CONFIG["host_alias"] = "i386-unknown-openbsd2.9"
   CONFIG["host_cpu"] = "i386"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd2.8"
+  CONFIG["host_os"] = "openbsd2.9"
+  CONFIG["target"] = "i386-unknown-openbsd2.9"
+  CONFIG["target_alias"] = "i386-unknown-openbsd2.9"
+  CONFIG["target_cpu"] = "i386"
+  CONFIG["target_vendor"] = "unknown"
+  CONFIG["target_os"] = "openbsd2.9"
+  CONFIG["build"] = "i386-unknown-openbsd2.9"
+  CONFIG["build_alias"] = "i386-unknown-openbsd2.9"
+  CONFIG["build_cpu"] = "i386"
+  CONFIG["build_vendor"] = "unknown"
+  CONFIG["build_os"] = "openbsd2.9"
   CONFIG["CC"] = "cc"
   CONFIG["CPP"] = "cc -E"
   CONFIG["YACC"] = "yacc"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["AR"] = "ar"
+  CONFIG["NM"] = ""
+  CONFIG["DLLWRAP"] = ""
+  CONFIG["AS"] = ""
+  CONFIG["DLLTOOL"] = ""
+  CONFIG["WINDRES"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
   CONFIG["LIBOBJS"] = ""
   CONFIG["ALLOCA"] = ""
-  CONFIG["DEFAULT_KCODE"] = ""
   CONFIG["XLDFLAGS"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["STATIC"] = ""
   CONFIG["CCDLFLAGS"] = "-fPIC"
-  CONFIG["LDSHARED"] = "ld -Bforcearchive -Bshareable"
+  CONFIG["LDSHARED"] = "$(CC) -shared -fPIC"
   CONFIG["DLEXT"] = "so"
+  CONFIG["DLEXT2"] = ""
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["LIBRUBY_LDSHARED"] = "ld -Bforcearchive -Bshareable"
+  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
+  CONFIG["PREP"] = ""
+  CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared -fPIC"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["RUBY_INSTALL_NAME"] = "ruby"
+  CONFIG["RUBY_SO_NAME"] = ""
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR).$(MINOR).$(TEENY)"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR).62"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
   CONFIG["SOLIBS"] = ""
-  CONFIG["arch"] = "i386-openbsd2.8"
-  CONFIG["sitedir"] = "/usr/local/lib/ruby/site_ruby"
+  CONFIG["DLDLIBS"] = "-lc"
+  CONFIG["ENABLE_SHARED"] = "yes"
+  CONFIG["arch"] = "i386-openbsd2.9"
+  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
   CONFIG["configure_args"] = "--enable-shared --with-tcl-include=/usr/local/include/tcl8.3 --with-tk-include=/usr/local/include/tk8.3 --with-X11-dir=/usr/X11R6 --prefix=/usr/local --sysconfdir=/etc"
   CONFIG["compile_dir"] = "/usr/obj/ports/lang/ruby/build-i386"
-  CONFIG.each_value do |val|
+  MAKEFILE_CONFIG = {}
+  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
+  def Config::expand(val)
     val.gsub!(/\$\(([^()]+)\)/) do |var|
       key = $1
       if CONFIG.key? key
-        "#{CONFIG[\"#{key}\"]}"
+        "#{Config::expand(CONFIG[\"#{key}\"])}"
       else
 	var
       end
     end
+    val
+  end
+  CONFIG.each_value do |val|
+    Config::expand(val)
   end
 end
